<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Leo Moll <leo@yeasoft.com>
 * @author Florian Anderiasch <fa@art-core.org>
 * @author Robin Kluth <commi1993@gmail.com>
 * @author Arne Pelka <mail@arnepelka.de>
 * @author Andreas Gohr <andi@splitbrain.org>
 * @author Dirk Einecke <dirk@dirkeinecke.de>
 * @author Blitzi94 <Blitzi94@gmx.de>
 * @author Robert Bogenschneider <robog@GMX.de>
 * @author Niels Lange <niels@boldencursief.nl>
 * @author Christian Wichmann <nospam@zone0.de>
 * @author Paul Lachewsky <kaeptn.haddock@gmail.com>
 * @author Pierre Corell <info@joomla-praxis.de>
 * @author Hella Breitkopf <hella.breitkopf@gmail.com>
 */
$lang['name']                  = 'Popularitäts-Feedback (längere Ladezeit möglich)';
$lang['submit']                = 'Daten senden';
$lang['autosubmit']            = 'Daten einmal im Monat automatisch senden';
$lang['submissionFailed']      = 'Die Daten konnten aufgrund des folgenden Fehlers nicht gesendet werden: ';
$lang['submitDirectly']        = 'Sie können die Daten durch Betätigung des Buttons manuell versenden.';
$lang['autosubmitError']       = 'Beim letzten automatischen Versuch die Daten zu senden, ist folgender Fehler aufgetreten: ';
$lang['lastSent']              = 'Die Daten wurden gesendet';
